@@ -52,10 +52,16 @@ header('Content-Type: application/json');
 try {
     $wpManager = new WordPressManager();
     $isRoot = AUTH_USER === 'root';
+    $username = AUTH_USER;
     $action = $_POST['action'] ?? $_GET['action'] ?? '';
-    
+
+    // Get database connection for backup queries
+    $mysql = new mysqlmgmt();
+    $db = $mysql->getMySQLConnection();
+    $db->exec("USE whp");
+
     error_log("WordPress AJAX: User=" . AUTH_USER . ", Action=" . $action . ", POST data: " . print_r($_POST, true));
-    
+
     switch ($action) {
         case 'update_wp_cli_support':
             if (!$isRoot) {
